#################################################
# Author : ViC
# Backup/Move Ebooks (Already Read)
#
# V. 1.0 : Initial version
# Backup files when :
# For Mobi files, a bookmark is set on first page
# For Pdf files, if current page is the first one
#################################################

import os.path
import glob
import sys

# Contains the default ebook subdirectory (normally 'ebooks')
ebookdir = "eBooks"
# Contains the name of the backup directory
ebookbakdir = "old"
# Display more debug informations (if set to True)
debug = False

# Global variables
separator = os.path.normcase('/')
ebookdir = separator + ebookdir + separator
ebookbakdir = separator + ebookbakdir + separator

# Read current value of 'status' File (Check information in mbp or dat files)
def checkReadStatus(filename):
	status = False
	f = open( filename,"rb") 
	line = f.read()
	pos = line.find("PooB") 
	# pdf file ? 
	if pos == 0:
		if debug: print filename + " is a pdf file"
		# get last page read in pdf file
		curPage = ord(line[pos+6]) + 256*ord(line[pos+5]) + 1
		if curPage == 1: status = True
	# or mobipocket file
	else: 
		if debug: print filename + " is a mobipocket file"
		pos = 0
		#check all bookmarks
		while True:
			pos = line.find("BKMK", pos) 
			if pos == -1: break
			# get page set for current bookmark
			curPage = ord(line[pos+23]) + 256*ord(line[pos+22])
			if curPage == 1: 
				status = True
				break
			# next bookmark
			pos = pos +1
	f.close() 

	return status

# Read directory (search ebooks files) 
def dirList(path, extension, readSubDir): 
	result=[]
	if debug: print "Explore directory :" + path
	# List all files and dirs
	for filename in glob.glob(path): 
		if os.path.isdir(filename):
			# Read subdirectory too 
			if readSubDir: 
				result.extend(dirList(filename + separator + "*", extension, readSubDir)) 
		else: 
			# Check the file extension
			for ext in extension.split(";"):
				if os.path.splitext(filename)[1].upper() == ext or ext == "":
					# File need to be processed
					result.append(filename)
					if debug: print "File : " + filename
		
	return result

# Backup/Move file
def processFile(filename):
	srcFile=[]
	for srcFile in dirList(os.path.splitext(filename)[0] + ".*", "", False):
		if debug: print "File Processed :" + srcFile
		dstFile = srcFile.replace(ebookdir, ebookbakdir)
		# Move the file read to backup directory
		os.renames(srcFile, dstFile)	

# Main code
if len(sys.argv) < 2:
  sys.exit("Usage : " + sys.argv[0] + " <directory>")

# backup ebooks (already read)
for filename in dirList(sys.argv[1],".MBP;.DAT", True): 
	if checkReadStatus(filename):
		processFile(filename)
print "Done..."
